#pragma once

#include <zephyr/kernel.h>
#include <zephyr/device.h>
#include <zephyr/drivers/gpio.h>
#include <stdbool.h>
#include <stdint.h>

#define BUTTON_ACTIVE_STATE (1)
typedef enum {
    BUTTON_EVENT_PRESSED,
    BUTTON_EVENT_RELEASED,
    BUTTON_EVENT_SHORT,
    BUTTON_EVENT_LONG,
    BUTTON_EVENT_EXTRA,
    BUTTON_EVENT_LONGEST
} button_event_type_t;

typedef struct {
    button_event_type_t type;
    uint32_t timestamp_ms;
} button_event_t;

/**
 * @brief Spustí detekci tlačítka na zadaném GPIO pinu
 *
 */
void TaskButton_Start();

/**
 * @brief Získá další událost z tlačítka (blokuje podle timeoutu)
 *
 * @param event Výstupní struktura s událostí
 * @param timeout Timeout pro čekání
 * @return 0 při úspěchu, jinak záporný kód chyby
 */
int TaskButton_GetEvent(button_event_t *event, k_timeout_t timeout);

/**
 * @brief Zjistí, zda je tlačítko právě stisknuté
 */
bool TaskButton_IsPressed(void);

/**
 * @brief Potlačí nebo povolí generování událostí
 *
 * @param suppress true = potlačit, false = povolit
 */
void TaskButton_Suppress(bool suppress);
